@@ -109,7 +109,7 @@ class WorkSheetParser(object):
         if style_id is not None:
             self.ws._styles[coordinate] = self.style_table.get(int(style_id))
 
-        if value is not None and value is not '':
+        if value is not None:
             cell = self.ws[coordinate]
             data_type = element.get('t', 'n')
             if data_type == Cell.TYPE_STRING:
